@@ -253,18 +253,13 @@ namespace lsvpd
 			 * @param size : buffer size
 			 */
 			unsigned int parsePciVPDBuffer( Component* fillMe,
-						        char * buf , int size );
+						        const char * buf , int size );
 	};
 
 	/**
 	 * device_open
 	 */
-	int device_open(int major, int minor, int mode, string& dev_path);
-
-	/**
-	 * device_close
-	 */
-	void device_close(int device_fd, string& dev_path);
+	int device_open(Component* fillMe);
 
 }
 #endif
